kittens
=======

Collection of Python utility functions for purr, tigger, meqtrees and others


Installation
------------

To install run::

    $ python setup.py install

 
Documentation
-------------

Read everything about MeqTrees on the wiki:

https://github.com/ska-sa/meqtrees/wiki

development
-----------

[![Build Status](https://travis-ci.org/ska-sa/kittens.svg?branch=master)](https://travis-ci.org/ska-sa/kittens)
